import 'package:flutter/material.dart';
import 'package:wowit/image_url.dart';
import 'package:wowit/message.dart';
import 'package:wowit/methods.dart';

class ThongTin1 {
  Widget getMainView(Map<String, dynamic> data, String tableName) {
    var dataReponse = Methods.getList(data['data'], tableName);
    if (dataReponse.isNotEmpty) {
      Map<String, Object?> itemSuKien = dataReponse[0];
      String hinhThuc = Methods.getString(itemSuKien, 'titleHinhThuc');      
      DateTime? thoiGianBatDauDangKy =
        Methods.getDateTime(itemSuKien, 'thoiGianBatDauDangKy');
      DateTime? thoiGianKetThucDangKy =
        Methods.getDateTime(itemSuKien, 'thoiGianKetThucDangKy');
      DateTime? thoiGianBatDauSuKien = Methods.getDateTime(itemSuKien, 'tgDienRaTu');
      DateTime? thoiGianKetThucSuKien = Methods.getDateTime(itemSuKien, 'tgDienRaDen');
      
      return Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Text(
            Methods.getString(itemSuKien, 'title'),
            maxLines: 3,
            style: const TextStyle(
              color: Colors.black,
              fontWeight: FontWeight.bold,
              fontSize: 18,
            ),
          ),
          if (thoiGianBatDauSuKien!=null && thoiGianKetThucSuKien !=null) ...[
            const SizedBox(height: 8),
            _iconTitle(
                icon: ImageByID.getUrlImage(
                    Methods.getInt(dataReponse[0], 'idIconThoiGian')),
                title: _textTime(thoiGianBatDauSuKien,thoiGianKetThucSuKien)),
          ],
          if (thoiGianBatDauDangKy!=null && thoiGianKetThucDangKy !=null) ...[
            const SizedBox(height: 8),
            _iconTitle(
                icon: ImageByID.getUrlImage(
                    Methods.getInt(dataReponse[0], 'idIconThoiGian')),
                title:Message.getMessage('SUKIEN_THOIGIANDANGKY')+ ' ' + _textTime(thoiGianBatDauDangKy,thoiGianKetThucDangKy)),
          ],
          const SizedBox(height: 8),
          _iconTitle(
            icon: ImageByID.getUrlImage(
              Methods.getInt(dataReponse[0], 'idIconDiaDiem'),
            ),
            title: Methods.getString(itemSuKien, 'diaDiemToChuc'),
          ),
          if (hinhThuc.isNotEmpty) ...[
            const SizedBox(height: 8),
            _iconTitle(
              icon: ImageByID.getUrlImage(
                Methods.getInt(dataReponse[0], 'idIconHinhThuc'),
              ),
              title: hinhThuc,
            ),
          ],
          const SizedBox(height: 8),
          _soLuongNguoiThamGia(itemSuKien,data['data'])
        ],
      );
    } else {
      return const SizedBox.shrink();
    }
  }

  Widget _iconTitle({
    required String icon,
    required String title,
  }) {
    return Row(
      children: [
        Image.network(
          Methods.getURL(icon),
          height: 20,
          width: 20,
        ),
        const SizedBox(
          width: 8,
        ),
        Expanded(child: Text(title, maxLines: 2))
      ],
    );
  }

  String _textTime(DateTime? dateTimeStart,DateTime? dateTimeEnd) {
    String textTime = '';
    if (Methods.showDate(dateTimeEnd) == Methods.showDate(dateTimeStart)) {
      textTime =
          '${_showTime(dateTimeStart)} - ${_showTime(dateTimeEnd)} : ${Methods.showDate(dateTimeStart)}';
    } else {
      textTime =
          '${_showDateTime(dateTimeStart)} - ${_showDateTime(dateTimeEnd)}';
    }
    return textTime;
  }

  String _showTime(DateTime? date) {
    if (date == null) {
      return '';
    }
    return _formatHourMinute(date.hour, date.minute);
  }

  String _showDateTime(DateTime? date) {
    if (date == null) {
      return '';
    }
    return '${Methods.showDate(date)} ${_formatHourMinute(date.hour, date.minute)}';
  }

  String _formatHourMinute(int hour, int minute) {
    return hour.toString().padLeft(2, '0') +
        ':' +
        minute.toString().padLeft(2, '0');
  }

  Widget _soLuongNguoiThamGia(Map<String,Object?> itemSuKien,Map<String, dynamic> data){
    int soLuong = Methods.getInt(itemSuKien, 'soNguoiThamGia');
    List<Map<String,Object?>?>? dsSoluong = Methods.getList(data, 'soluong');
    if(soLuong>0){
      int soNguoiDangKy = 0;
      if(dsSoluong.isNotEmpty){
        soNguoiDangKy = Methods.getInt(dsSoluong.first, 'soluong');
      }
      soLuong -=soNguoiDangKy;  
      if(soLuong>0){
        return _iconTitle(
            icon: ImageByID.getUrlImage(2233),
            title: Message.getMessage('SUKIEN_CON_TRONG_SLOT1') + ' $soLuong ' + Message.getMessage('SUKIEN_CON_TRONG_SLOT2'),
          );
      }else{
        return _iconTitle(
            icon: ImageByID.getUrlImage(2233),
            title: Message.getMessage('SUKIEN_HET_SLOT'),
          );
      }
    }
    return Container();
  }
  
}
